# Generated by Django 2.1.7 on 2019-02-12 08:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nuntius', '0006_subscriber_verbose_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaign',
            name='message_content_text',
            field=models.TextField(blank=True, verbose_name='Message content (text)'),
        ),
    ]
